@@ -223,14 +223,14 @@ class Chemical:
              Pc: 2.2048e+07 Pa
              Vc: 5.6e-05 m^3/mol
              Hf: -2.4182e+05 J/mol
-             LHV: None
-             HHV: None
+             LHV: 0
+             HHV: 0
              Hfus: 6010 J/mol
              omega: 0.344
              dipole: None
              similarity_variable: 0.16653
              iscyclic_aliphatic: 0
-             combustion: None
+             combustion: {}
 
     All fields shown are accessible:
     
@@ -507,7 +507,8 @@ class Chemical:
         return self
 
     @classmethod
-    def blank(cls, ID, CAS=None, phase_ref=None, phase=None, **data):
+    def blank(cls, ID, CAS=None, phase_ref=None, phase=None,
+              formula=None, **data):
         """
         Return a new Chemical object without any thermodynamic models or data (unless provided).
 
@@ -593,7 +594,8 @@ class Chemical:
         for i,j in data.items(): setfield(self, '_' + i , j)
         self._eos = create_eos(PR, self._Tc, self._Pc, self._omega)
         self._eos_1atm = self._eos.to_TP(298.15, 101325)
-        if self._formula: self.reset_combustion_data()
+        if formula: self.formula = formula
+        else: self._formula = formula
         return self
 
     def copy(self, ID, CAS=None):
