@@ -233,8 +233,9 @@ class CompiledChemicals(Chemicals):
     >>> # TypeError: 'CompiledChemicals' object is read-only
         
     
-    """
+    """  
     _cache = {}
+    
     def __new__(cls, chemicals):
         isa = isinstance
         chemicals = tuple([chem if isa(chem, Chemical) else Chemical(chem)
@@ -270,19 +271,6 @@ class CompiledChemicals(Chemicals):
         including the molecular weight, heats of formation,
         and heats of combustion.
         
-        Examples
-        --------
-        Some chemical constants may not be defined in thermosteam, 
-        such as the heat of combustion.
-        We can update it and refresh the compiled constants:
-        
-        >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Glucose'])
-        >>> chemicals.Glucose.HHV = -2291836.024
-        >>> chemicals.refresh_constants()
-        >>> chemicals.HHV
-        array([-2291836.024])
-        
         """
         dct = self.__dict__
         chemicals = self.tuple
@@ -293,22 +281,25 @@ class CompiledChemicals(Chemicals):
 
     def get_combustion_reactions(self):
         """Return a ParallelReactions object with all defined combustion reactions."""
-        reactions = [i.get_combustion_reaction(self) 
-                         for i in self if i.combustion]
+        reactions = [i.get_combustion_reaction(self)
+                     for i in self if i.combustion]
         return tmo.reaction.ParallelReaction(reactions)
 
     def _compile(self):
         dct = self.__dict__
         tuple_ = tuple
         chemicals = tuple_(dct.values())
+        free_energies = ('H', 'S', 'H_excess', 'S_excess')
         for chemical in chemicals:
+            if chemical.get_missing_properties(free_energies):
+                chemical.reset_free_energies()
             key_properties = chemical.get_key_property_names()
-            missing_slots = chemical.get_missing_slots(key_properties)
-            if not missing_slots: continue
-            missing = repr_listed_values(missing_slots)
+            missing_properties = chemical.get_missing_properties(key_properties)
+            if not missing_properties: continue
+            missing = repr_listed_values(missing_properties)
             raise RuntimeError(
                 f"{chemical} is missing key thermodynamic properties ({missing}); "
-                "use the `<Chemical>.get_missing_slots()` to check "
+                "use the `<Chemical>.get_missing_properties()` to check "
                 "all missing properties")
         IDs = tuple_([i.ID for i in chemicals])
         CAS = tuple_([i.CAS for i in chemicals])
@@ -636,6 +627,7 @@ class CompiledChemicals(Chemicals):
         try: 
             index = cache[IDs]
         except KeyError: 
+            if len(cache) > 1000: cache.clear()
             cache[IDs] = index = self._get_index(IDs)
         except TypeError:
             raise TypeError("only strings, tuples, and ellipsis are valid index keys")
