@@ -4,7 +4,7 @@ from . import functor
 from . import thermo_model
 from . import thermo_model_handle
 from . import handle_builder
-from . import phase_property
+from . import phase_handle
 from . import units_of_measure
 from . import documenter
 
@@ -12,7 +12,7 @@ __all__ = (*functor.__all__,
            *thermo_model.__all__,
            *thermo_model_handle.__all__,
            *handle_builder.__all__,
-           *phase_property.__all__,
+           *phase_handle.__all__,
            *units_of_measure.__all__,
            *documenter.__all__)
 
@@ -20,7 +20,7 @@ from .functor import *
 from .thermo_model import *
 from .thermo_model_handle import *
 from .handle_builder import *
-from .phase_property import *
+from .phase_handle import *
 from .units_of_measure import *
 from .documenter import *
 
