@@ -40,19 +40,19 @@ class Documenter:
         else:
             return types.get(var, 'float')
 
-    def describe_functor(self, functor, equation, ref):
+    def describe_functor(self, functor, method, ref):
         var = functor.var
         if var:
             return_value = self.describe_return_value(var)
             description = f"Create a {functor.kind} that calcuates {return_value}"
-            if equation:
-                description += f" using the {equation} equation"
+            if method:
+                description += f" using the {method} method"
             if ref:
                 description += f", as described in {ref}"
         else:
             description = f"Create a {functor.kind}"
-            if equation:
-                description += f"based on the {equation} equation"
+            if method:
+                description += f" based on the {method} method"
             if ref:
                 description += f", as described in {ref}"
         return description + "."
@@ -104,8 +104,9 @@ class Documenter:
 
 # %% Autodoc
 
-def autodoc_functor(functor, doc='auto-merge', equation=None, ref=None, tabs=1,
-                    units_of_measure=None, definitions=None, types=None):
+def autodoc_functor(functor, doc='auto-merge', method=None, ref=None, tabs=1,
+                    units_of_measure=None, definitions=None, types=None,
+                    other_params=None):
     auto = merge = header = param = False
     if doc == 'auto-doc':
         auto = True
@@ -121,13 +122,17 @@ def autodoc_functor(functor, doc='auto-merge', equation=None, ref=None, tabs=1,
     autodoc = Documenter(units_of_measure, definitions, types)
     function = functor.function
     header = autodoc.describe_functor(functor,
-                                      equation or function.__name__.replace('_', ' '),
+                                      method or function.__name__.replace('_', ' '),
                                       ref)
     function_doc = function.__doc__ or ""
     function.__doc__ = None
-    params = functor.params
     new_line = "\n" + (tabs * 4) * " "
-    parameters = autodoc.describe_all_parameters(params, new_line) if params else "" 
+    params = functor.params
+    if header:
+        if other_params:
+            params = list(params)
+            for i in other_params: params.remove(i)
+        parameters = autodoc.describe_all_parameters(params, new_line) if params else "" 
     
     if auto:
         functor.__doc__ = _join_sections(header, parameters, new_line)
