@@ -9,13 +9,13 @@ from ..utils import var_with_units, get_obj_values, repr_kwargs
 from .documenter import autodoc_functor
 from inspect import signature
 
-__all__ = ("Functor",  "TFunctor", "TPFunctor", "TIntegralFunctor",
-           "functor", 'H', 'S', 'V', 'Cn', 'mu', 'kappa', 'sigma', 'delta', 'epsilon',
+__all__ = ("functor", "Functor",  "TFunctor", "TPFunctor", "TIntegralFunctor",
+           'H', 'S', 'V', 'Cn', 'mu', 'kappa', 'sigma', 'delta', 'epsilon',
            'Psat', 'Hvap', 'display_asfunctor', 'functor_lookalike',
-           'functor_matching_params', 'functor_base_and_params',)
+           'functor_matching_params')
 
-RegisteredArgs = set()
-RegisteredFunctors = []
+REGISTERED_ARGS = set()
+REGISTERED_FUNCTORS = []
 
 # %% Utilities
 
@@ -41,20 +41,24 @@ def functor_lookalike(cls):
     return cls
 
 def functor_matching_params(params):
-    length = len
-    N_total = length(params)
-    for base in RegisteredFunctors:
-        args = base._args
-        N = length(args)
-        if N > N_total: continue
-        if args == params[:N]: return base
+    N_total = len(params)
+    for base in REGISTERED_FUNCTORS:
+        N = base._N_args
+        if N <= N_total and base._args == params[:N]: return base
     raise ValueError("could not match function signature to registered functors")
 
-def functor_base_and_params(function):
+def functor_arguments(function):
     params = tuple(signature(function).parameters)
+    first_param = params[0]
+    if first_param == 'self':
+        params = params[1:]
+    elif first_param == 'cls':
+        params = params[1:]
+        function = classmethod(function)
+    else:
+        function = staticmethod(function)
     base = functor_matching_params(params)
-    return base, params[len(base._args):]
-
+    return base, params[base._N_args:], function
 
 # %% Decorator
   
@@ -99,9 +103,9 @@ def functor(f=None, var=None, **autodoc):
     
     """
     if f:
-        base, params = functor_base_and_params(f)
+        base, params, function = functor_arguments(f)
         dct = {'__slots__': (),
-               'function': staticmethod(f),
+               'function': function,
                'params': params,
                'var': var}
         cls = type(f.__name__, (base,), dct)
@@ -143,65 +147,71 @@ H, S, Cn, V, kappa, mu, Psat, Hvap, sigma, delta, epsilon = [FunctorFactory(i) f
 
 # %% Functors
 
-class Functor: 
+class Functor:
+    __slots__ = ('__dict__',)
     definitions = definitions
     types = types
-    
-    def __init_subclass__(cls, args=None, before=None, after=None):
-        if args and not hasattr(cls, 'function'):
-            args = tuple(args)
-            assert args not in RegisteredArgs, f"abstract functor with args={args} already implemented"
-            if before:
-                index = RegisteredFunctors.index(before)
-            elif after:
-                index = RegisteredFunctors.index(after) + 1
-            else:
-                index = 0
-            RegisteredFunctors.insert(index, cls)
-            RegisteredArgs.add(args)
-            cls._args = args
+    def __init_subclass__(cls, args=None):
+        if args:
+            cls._args = args = tuple(args)
+            cls._N_args = N_args = len(args)
+            assert args not in REGISTERED_ARGS, (
+                f"abstract functor with args={args} already implemented")
+            REGISTERED_ARGS.add(args)
+            index = 0
+            for index, Functor in enumerate(REGISTERED_FUNCTORS):
+                if Functor._N_args <= N_args: break
+            REGISTERED_FUNCTORS.insert(index, cls)
     
     def __init__(self, *args, **kwargs):
         for i, j in zip(self.params, args): kwargs[i] = j
-        self.data = kwargs
+        self.__dict__ = kwargs
     
-    @property
-    def data(self):
-        return self.__dict__
-    @data.setter
-    def data(self, data):
-        self.__dict__ = data
+    def set_value(self, var, value):
+        if var in self.__dict__:
+            self.__dict__[var] = value
+    
+    def copy(self):
+        cls = self.__class__
+        new = cls.__new__(cls)
+        new.__dict__ = self.__dict__.copy()
+        return new
+    
+    def load_data_from(self, data: dict):
+        dct = self.__dict__
+        keys = dct.keys() & data.keys()
+        for i in keys: dct[i] = data[i]
     
     @classmethod
     def from_other(cls, other):
         self = cls.__new__(cls)
-        self.data = other.data
+        self.__dict__ = other.__dict__
         return self
     
     @classmethod
     def from_args(cls, data):
         self = cls.__new__(cls)
-        self.data = dict(zip(self.params, data))
+        self.__dict__ = dict(zip(self.params, data))
         return self
     
     @classmethod
     def from_kwargs(cls, data):
         self = cls.__new__(cls)
-        self.data = data
+        self.__dict__ = data
         return self
     
     @classmethod
     def from_obj(cls, data):
         self = cls.__new__(cls)
-        self.data = dict(zip(self.params, get_obj_values(data, self.params)))
+        self.__dict__ = dict(zip(self.params, get_obj_values(data, self.params)))
         return self
     
     def _object_info(self):
-        return f"{type(self).__name__}({repr_kwargs(self.data, start='')})"
+        return f"{type(self).__name__}({repr_kwargs(self.__dict__, start='')})"
     
     def _functor_info(self):
         info = f"Functor: {display_asfunctor(self)}"
-        data = self.data
+        data = self.__dict__
         for key, value in data.items():
             if callable(value):
                 value = display_asfunctor(value, show_var=False)
@@ -251,22 +261,24 @@ class Functor:
 
 
 class TFunctor(Functor, args=('T',)):
+    __slots__ = ()
     kind = "functor of temperature (T; in K)"
     def __call__(self, T, P=None):
         return self.function(T, **self.__dict__)
 
+class TPFunctor(Functor, args=('T', 'P')):
+    __slots__ = ()
+    kind = "functor of temperature (T; in K) and pressure (P; in Pa)"
+    def __call__(self, T, P):
+        return self.function(T, P, **self.__dict__)
 
 class TIntegralFunctor(Functor, args=('Ta', 'Tb')):
+    __slots__ = ()
     kind = "temperature integral functor (Ta to Tb; in K)"
     def __call__(self, Ta, Tb, P=None):
         return self.function(Ta, Tb, **self.__dict__)
 
 
-class TPFunctor(Functor, args=('T', 'P')):
-    kind = "functor of temperature (T; in K) and pressure (P; in Pa)"
-    def __call__(self, T, P):
-        return self.function(T, P, **self.__dict__)
-
 
     
     
