@@ -5,6 +5,7 @@ __all__ = ('UndefinedChemical',
            'UndefinedPhase',
            'UndefinedPhaseOrChemical',
            'DimensionError',
+           'DomainError',
            'message_with_object_stamp',
            'try_method_with_object_stamp',
            'raise_error_with_object_stamp')
@@ -24,6 +25,9 @@ class UndefinedPhaseOrChemical(AttributeError):
 class DimensionError(ValueError):
     """ValueError regarding wrong dimensions."""
 
+class DomainError(ValueError):
+    """ValueError regarding an attempt to evaluate a model out of its domain."""
+
 def message_with_object_stamp(object, msg):
     object_name = repr(object)
     if object_name in msg:
