@@ -4,14 +4,9 @@ Created on Mon Dec  2 01:41:50 2019
 
 @author: yoelr
 """
-
+import thermosteam as tmo
 from .base import AbsoluteUnitsOfMeasure
-from .utils import (repr_IDs_data, repr_couples,
-                    chemicals_user,
-                    same_chemicals, same_phases,
-                    all_same_chemicals,
-)
-from ._settings import settings
+from . import utils
 from .exceptions import UndefinedPhase, UndefinedChemical
 from ._phase import Phase, LockedPhase, NoPhase
 from free_properties import PropertyFactory, property_array
@@ -107,7 +102,7 @@ class Indexer:
 
 # %% Phase data
 
-@chemicals_user
+@utils.chemicals_user
 class ChemicalIndexer(Indexer):
     """
     Create a ChemicalIndexer that can index a single-phase, 1d-array given
@@ -135,6 +130,7 @@ class ChemicalIndexer(Indexer):
     
     def __new__(cls, phase, units=None, chemicals=None, **ID_data):
         if ID_data:
+            chemicals = tmo.settings.get_default_chemicals(chemicals)
             self = cls.from_data(chemicals.kwarray(ID_data), phase, chemicals)
             if units: self.set_data(self._data, units)
         else:
@@ -161,8 +157,8 @@ class ChemicalIndexer(Indexer):
         self._data[:] = 0
     
     def mix_from(self, others):
-        all_same_chemicals(self, others)
-        self.phase = find_main_phase(others[1:], others[0]) or self.phase
+        utils.all_same_chemicals(self, others)
+        self.phase = find_main_phase(others[1:], others[0])
         self._data[:] = sum([i.sum_across_phases() for i in others])
     
     def to_material_indexer(self, phases=()):
@@ -171,7 +167,7 @@ class ChemicalIndexer(Indexer):
         return material_array
     
     def copy_like(self, other):
-        same_chemicals(self, other)
+        utils.same_chemicals(self, other)
         self._data[:] = other._data
         self.phase = other.phase
     
@@ -221,7 +217,7 @@ class ChemicalIndexer(Indexer):
             phase = '\n' + tab + phase
         else:
             dlim = ", "
-        ID_data = repr_IDs_data(self._chemicals.IDs, self._data, dlim)
+        ID_data = utils.repr_IDs_data(self._chemicals.IDs, self._data, dlim)
         return f"{type(self).__name__}({phase}{ID_data})"
     
     def __repr__(self):
@@ -229,7 +225,6 @@ class ChemicalIndexer(Indexer):
     
     def _info(self, N):
         """Return string with all specifications."""
-        from thermosteam import Stream
         IDs = self.chemicals.IDs
         data = self.data
         IDs, data = nonzeros(IDs, data)
@@ -245,7 +240,7 @@ class ChemicalIndexer(Indexer):
         data_info = ''
         lengths = [len(i) for i in IDs]
         maxlen = max(lengths) + 1
-        N_max = N or Stream.display_units.N
+        N_max = N or tmo.Stream.display_units.N
         too_many_chemicals = N_IDs > N_max
         N = N_max if too_many_chemicals else N_IDs
         for i in range(N):
@@ -271,7 +266,7 @@ class ChemicalIndexer(Indexer):
         print(self._info(N))
     _ipython_display_ = show
       
-@chemicals_user
+@utils.chemicals_user
 class MaterialIndexer(Indexer):
     """
     Create a MaterialIndexer that can index a multi-phase, 2d-array given
@@ -324,24 +319,26 @@ class MaterialIndexer(Indexer):
         self._data[:] = 0
     
     def copy_like(self, other):
-        same_chemicals(self, other)
+        utils.same_chemicals(self, other)
         if isa(other, ChemicalIndexer):
             self.empty()
             self[other.phase] = other._data
         else:
-            same_phases(self, other)
+            utils.same_phases(self, other)
             self._data[:] = other._data
     
     def mix_from(self, others):
-        all_same_chemicals(self, others)
-        self.empty()
+        utils.all_same_chemicals(self, others)
         isa = isinstance
+        data = self._data
+        data[:] = 0
+        get_phase_index = self._get_phase_index
         for i in others:
             if isa(i, MaterialIndexer):
-                same_phases(self, i)
-                self._data[:] += i._data
+                utils.same_phases(self, i)
+                data[:] += i._data
             elif isa(i, ChemicalIndexer):
-                self[i.phase] += i._data
+                data[get_phase_index(i.phase)] += i._data
             else:
                 raise ValueError("can only mix from chemical or material indexers")
     
@@ -438,6 +435,7 @@ class MaterialIndexer(Indexer):
                 index = self._get_index(key)
             else:
                 index = ChemicalIndex(index)
+            if len(cache) > 1000: cache.clear()
             cache[key] = index
         except TypeError:
             raise TypeError("only strings, tuples, and ellipsis are valid index keys")
@@ -491,7 +489,7 @@ class MaterialIndexer(Indexer):
         IDs = self._chemicals.IDs
         phase_data = []
         for phase, data in self:
-            ID_data = repr_couples(", ", IDs, data)
+            ID_data = utils.repr_couples(", ", IDs, data)
             if ID_data:
                 phase_data.append(f"{phase}=[{ID_data}]")
         tabs = int(tabs) if tabs else 1
@@ -701,7 +699,7 @@ def by_volume(self, TP):
         for i, phase in enumerate(phases):
             for j, chem in enumerate(chemicals):
                 index = i, j
-                phase_name = settings._phase_names[phase]
+                phase_name = tmo.settings._phase_names[phase]
                 vol[index] = VolumetricFlowProperty(f"{phase_name}{chem.ID}", 
                                                     mol, index, chem.V, TP, phase)
         self._data_cache[TP] = \
