@@ -39,7 +39,7 @@ from math import log, exp
 from cmath import log as clog, exp as cexp
 import numpy as np
 from ..base import InterpolatedTDependentModel, thermo_model, TDependentHandleBuilder, \
-                   PhaseTPropertyBuilder, S, H, Cn
+                   PhaseTHandleBuilder, S, H, Cn
 from .utils import to_nums, CASDataReader
 from .._constants import R, calorie
 from ..functional import polylog2
@@ -948,4 +948,4 @@ def heat_capacity_solid_handle(handle, CAS, similarity_variable, MW):
         add_model(CnHSModel(*Lastovka_Solid_Functors, data), Tmin, Tmax,
                   name=LASTOVKA_S)
 
-heat_capacity_handle = PhaseTPropertyBuilder('Cn', heat_capacity_solid_handle, heat_capacity_liquid_handle, heat_capacity_gas_handle)
+heat_capacity_handle = PhaseTHandleBuilder('Cn', heat_capacity_solid_handle, heat_capacity_liquid_handle, heat_capacity_gas_handle)
