@@ -70,8 +70,7 @@ __all__ = ('REFPROP',
            'Sastri_Rao', 
            'Zuo_Stenby',
            'Hakim_Steinberg_Stiel', 
-           'Miqueu', 
-           'Aleem', 
+           'Miqueu',
            'Mersmann_Kind_surface_tension'
 )
 
@@ -390,66 +389,6 @@ def Miqueu(T, Tc, Vc, omega):
     Vc = Vc*1E6
     t = 1.-T/Tc
     return k*Tc*(N_A/Vc)**(2/3.)*(4.35 + 4.14*omega)*t**1.26*(1+0.19*t**0.5 - 0.25*t)*10000
-    
-@sigma(doc='auto-merge', ref='[13]_')
-def Aleem(T, MW, Tb, rho_l, Hvap_Tb, Cp_l):
-    r'''
-    Parameters
-    ----------
-    T : float
-        Temperature of fluid [K]
-    MW : float
-        Molecular weight [g/mol]
-    Tb : float
-        Boiling temperature of the fluid [K]
-    rho_l : float
-        Liquid density at T and P [kg/m^3]
-    Hvap_Tb : float
-        Enthalpy of vaporization at the normal boiling point [J/g]
-    Cp_l : float
-        Liquid heat capacity of the chemical at T [J/kg/K]
-    
-    Notes
-    -----
-    Calculates vapor-liquid surface tension using the correlation derived by
-    [13]_ based on critical property CSP methods.
-    
-    .. math::
-        \sigma = \phi \frac{MW^{1/3}} {6N_A^{1/3}}\rho_l^{2/3}\left[H_{vap}
-        + C_{p,l}(T_b-T)\right]
-        
-        \phi = 1 - 0.0047MW + 6.8\times 10^{-6} MW^2
-    
-    Internal units of molecuar weight are kg/mol. This model is dimensionally
-    consistent.
-    
-    This model does not use the critical temperature. After it predicts a 
-    surface tension of 0 at a sufficiently high temperature, it returns 
-    negative results. The temperature at which this occurs (the "predicted"
-    critical temperature) can be calculated as follows:
-        
-    .. math::
-        \sigma = 0 \to T_{c,predicted} \text{ at } T_b + \frac{H_{vap}}{Cp_l}
-    
-    Because of its dependence on density, it has the potential to model the 
-    effect of pressure on surface tension.
-    
-    Claims AAD of 4.3%. Developed for normal alkanes. Total of 472 data points. 
-    Behaves worse for higher alkanes. Behaves very poorly overall.
-    
-    Examples
-    --------
-    Methane at 90 K:
-    
-    >>> f = Aleem(MW=16.04246, Tb=111.6, rho_l=458.7, Hvap_Tb=510870.,
-    ... Cp_l=2465.)
-    >>> f(T=90)
-    0.01669970221165325
-    
-    '''
-    MW = MW/1000. # Use kg/mol for consistency with the other units
-    sphericity = 1. - 0.0047*MW + 6.8E-6*MW*MW
-    return sphericity*MW**(1/3.)/(6.*N_A**(1/3.))*rho_l**(2/3.)*(Hvap_Tb + Cp_l*(Tb-T))
 
 @sigma(other_params=['n_associated'], ref='[14]_')
 def Mersmann_Kind_surface_tension(T, Tm, Tb, Tc, Pc, n_associated=1):
@@ -489,7 +428,7 @@ def Mersmann_Kind_surface_tension(T, Tm, Tb, Tc, Pc, n_associated=1):
     return sigma
 
 @TDependentHandleBuilder('sigma')
-def surface_tension_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPolar, Hvap_Tb, rho_l, Cp_l_Tb):
+def surface_tension_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPolar):
     add_model = handle.add_model
     if CAS in _Mulero_Cachadina:
         _, sigma0, n0, sigma1, n1, sigma2, n2, Tc, Tmin, Tmax = _Mulero_Cachadina[CAS]
@@ -530,10 +469,3 @@ def surface_tension_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPola
         _, Tm, Tc, a, b, c, d, e = _VDI_PPDS_11[CAS]
         VDI_PPDS_coeffs = (Tc, a, b, c, d, e)
         add_model(DIPPR_EQ106.from_args(VDI_PPDS_coeffs))
-    data = (MW, Tb, rho_l, Hvap_Tb, Cp_l_Tb)
-    if all(data):
-        Tmax = Tb + Hvap_Tb/Cp_l_Tb
-        # This method will ruin solve_prop as it is typically valids
-        # well above Tc. If Tc is available, limit it to that.
-        if Tc: Tmax = min(Tc, Tmax)
-        add_model(Aleem.from_args(data))
