@@ -395,7 +395,7 @@ def Missenard(T, P, Tc, Pc, k_l):
     return k_l*(1. + Q*Pr**0.7)
 
 @TPDependentHandleBuilder('kappa.l')
-def thermal_conductivity_liquid_handle(handle, CAS, MW, Tm, Tb, Tc, Pc, omega, Hfus):
+def thermal_conductivity_liquid_handle(handle, CAS, MW, Tm, Tb, Tc, Pc, omega):
     add_model = handle.add_model
     if all((Tc, Pc)):
         data = (Tc, Pc, handle)
