@@ -326,7 +326,7 @@ class SeriesReaction(ReactionSet):
         X_net = {}
         for i, j in zip(self.reactants, self.X):
             if i in X_net:
-                X_net[i] *= j
+                X_net[i] += (1 - X_net[i]) * j
             else:
                 X_net[i] = j
         chemicals = self.chemicals
